==> level-promisify-0.1.1.tgz: package/test.js <==
#!/usr/bin/env node

var rimraf = require( 'rimraf' ),
    argv = require( 'minimist' )( process.argv.slice( 2 ) ),
    chalk = require( 'chalk' ),

    Promise = require( 'es6-promise' ).Promise,

    LP = require( './' ),
    db = './db',
    subdb = './subdb';


process.on( 'exit', function( status ) {
    console.log( '\nExiting...' );

    if ( argv.c ) {
        console.log( chalk.blue( 'Removing db' ) );
        rimraf.sync( db );
        rimraf.sync( subdb );
    }
});

function onSuccess( res, cb ) {
    console.log( 'resolved -', res || 'done' );

    if ( cb ) cb();
}

function onError( err ) {
    console.error( 'rejected -', err );
}

// LP( './ttdb' )
//     .then( function( db ) {
//         db.put( 'foo', 'bar' )
//             .catch( function( err ) {
//                 console.log( err );
//             });
//     });

var l = LP( db, {
    valueEncoding:'json',
    sync: true,
    sublevel: true
});

l.on( 'put', function() {
    console.log( 'put event fired' );
});

function testPut( key, val ) {
    return l.put( key, val );
}

function testGet( key ) {
    return l.get( key );
}

// l.batch([
//     {
//         type: 'put',
//         key: 'testing',
//         value: 'batch'
//     }, {
//         type: 'put',
//         key: 'testy',
//         value: 'batchy'
//     }
// ]).then( onSuccess )
//     .catch( onError );

// l.batch()
//     .put( 'name', 'dmitri' )
//     .put( 'namo', 'tutrle' )
//     .write( function() {
//         console.log( 'all written' );
//     });

testPut( 'b', 'braben' )
    .then( function() {
        return testGet( 'b' )
    })
    .then( console.log )
    .catch( onError );

// testGet( 'a' )
//     .then( function( val ) {
//         return testPut( val, val + '\xff' + Date.now() )
//     })
//     .catch( onError );
//
// Promise.all([
//     { a: 'arca' },
//     { b: 'boulb' },
//     { c: 'cat' },
//     { d: 'damien' },
//     { e: 'ello' }
// ].map( function( pair ) {
//     var key = Object.keys( pair )[0];
//     return testPut( key, pair[ key ] );
// }))
//     .then( function( res ) {
//         console.log( 'added all the data' );
//     })
//     .then( function() {
//         return testGet( 'a' );
//     })
//     .then( onSuccess )
//     .then( function() {
//         l.get( 'c' )
//             .then( onSuccess );
//     })
//     .then( function() {
//         l.createReadStream()
//             .on( 'data', function( data ) {
//                 console.log( data );
//             })
//             .on( 'error', function( err ) {
//                 console.log( 'stream error: ', err );
//             })
//             .on( 'end', function() {
//                 console.log( 'finished reading data' );
//             });
//     })
//     .catch( onError );

// var sl = LP( subdb, {
//     valueEncoding: 'json',
//     sync: true,
//     sublevel: true
// });

==> level-promisify-0.1.2.tgz: package/test.js <==
#!/usr/bin/env node

var rimraf = require( 'rimraf' ),
    argv = require( 'minimist' )( process.argv.slice( 2 ) ),
    chalk = require( 'chalk' ),

    Promise = require( 'es6-promise' ).Promise,

    LP = require( './' ),
    db = './db',
    subdb = './subdb';


process.on( 'exit', function( status ) {
    console.log( '\nExiting...' );

    if ( argv.c ) {
        console.log( chalk.blue( 'Removing db' ) );
        rimraf.sync( db );
        rimraf.sync( subdb );
    }
});

function onSuccess( res, cb ) {
    console.log( 'resolved -', res || 'done' );

    if ( cb ) cb();
}

function onError( err ) {
    console.error( 'rejected -', err );
}

// LP( './ttdb' )
//     .then( function( db ) {
//         db.put( 'foo', 'bar' )
//             .catch( function( err ) {
//                 console.log( err );
//             });
//     });

var l = LP( db, {
    valueEncoding:'json',
    sync: true,
    sublevel: true
});

l.on( 'put', function() {
    console.log( 'put event fired' );
});

function testPut( key, val ) {
    return l.put( key, val );
}

function testGet( key ) {
    return l.get( key );
}

// l.batch([
//     {
//         type: 'put',
//         key: 'testing',
//         value: 'batch'
//     }, {
//         type: 'put',
//         key: 'testy',
//         value: 'batchy'
//     }
// ]).then( onSuccess )
//     .catch( onError );

// l.batch()
//     .put( 'name', 'dmitri' )
//     .put( 'namo', 'tutrle' )
//     .write( function() {
//         console.log( 'all written' );
//     });

// testPut( 'b', 'braben' )
//     .then( function() {
//         return testGet( 'b' )
//     })
//     .then( console.log )
//     .catch( onError );

// testGet( 'a' )
//     .then( function( val ) {
//         return testPut( val, val + '\xff' + Date.now() )
//     })
//     .catch( onError );
//
Promise.all([
    { a: 'arca' },
    { b: 'boulb' },
    { c: 'cat' },
    { d: 'damien' },
    { e: 'ello' }
].map( function( pair ) {
    var key = Object.keys( pair )[0];
    return testPut( key, pair[ key ] );
}))
    .then( function( res ) {
        console.log( 'added all the data' );
    })
    .then( function() {
        return testGet( 'a' );
    })
    .then( onSuccess )
    .then( function() {
        l.get( 'c' )
            .then( onSuccess );
    })
    .then( function() {
        l.createReadStream()
            .on( 'data', function( data ) {
                console.log( data );
            })
            .on( 'error', function( err ) {
                console.log( 'stream error: ', err );
            })
            .on( 'end', function() {
                console.log( 'finished reading data' );
            });
    })
    .catch( onError );

// var sl = LP( subdb, {
//     valueEncoding: 'json',
//     sync: true,
//     sublevel: true
// });
